@@ -5,7 +5,7 @@ from datetime import date
 import asyncio
 
 from graphql import GraphQLError
-from graphql.type.definition import GraphQLObjectType, GraphQLEnumType, get_named_type, is_list_type
+from graphql.type.definition import GraphQLObjectType, GraphQLEnumType, get_named_type, is_list_type, is_non_null_type
 from ariadne import UnionType
 from ariadne.types import GraphQLResolveInfo
 from sqlalchemy import select, cast, String
@@ -48,6 +48,17 @@ def get_one_field(info, q):
     return get_dbsession(info).execute(q).scalar()
 
 
+def separate_filters(filters: list, to_separate: str):
+    newfilters = []
+    separated = None
+    for f in filters:
+        if f['field_name'] == to_separate:
+            separated = f
+        else:
+            newfilters.append(f)
+    return newfilters, separated
+
+
 def resolve_type_inspector(_, info: GraphQLResolveInfo, type_name):
     gqltype = info.schema.get_type(type_name)
     if gqltype is None or not isinstance(gqltype, GraphQLObjectType):
@@ -71,8 +82,8 @@ def resolve_type_inspector(_, info: GraphQLResolveInfo, type_name):
             if field_type is None:
                 raise Exception('Can only filter on Named Types')
             # Deducing filter type by GraphQL type. Contrary to simple_table_resolver
-            if is_list_type(field.type):  # If list, it means it's a postgresql array and only = comparator works
-                field_filter_type = 'LIST'
+            if is_list_type(field.type) or (is_non_null_type(field.type) and is_list_type(field.type.of_type)):
+                field_filter_type = 'LIST'  # If list, it means it's a postgresql array and only = comparator works
             elif field_type.name == 'String':
                 field_filter_type = 'STRING'
             elif field_type.name in ['Int', 'Float']:
